@@ -1,12 +1,12 @@
 /*
   Copyright @ 2018 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
-  
+
   You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
-  
+
     https://imagemagick.org/script/license.php
-  
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -20,12 +20,12 @@
 
 #include "utils.cc"
 
-extern "C" int LLVMFuzzerTestOneInput(const uint8_t *Data, size_t Size) {
+extern "C" int LLVMFuzzerTestOneInput(const uint8_t *Data, size_t Size)
+{
   uint16_t Width;
   uint16_t Height;
-  if (Size < (sizeof(Width) + sizeof(Height))) {
+  if (IsInvalidSize(Size, sizeof(Width) + sizeof(Height)))
     return 0;
-  }
   Width = *reinterpret_cast<const uint16_t *>(Data);
   Height = *reinterpret_cast<const uint16_t *>(Data + sizeof(Width));
   const Magick::Blob blob(Data + sizeof(Width) + sizeof(Height),
