@@ -14,7 +14,8 @@
   limitations under the License.
 */
 
-class EncoderFormat {
+class EncoderFormat
+{
 public:
   std::string get() { return std::string(_format.begin(), _format.end()); } const
   void set(const std::wstring fileName, const std::wstring extension)
