@@ -1,12 +1,12 @@
 /*
   Copyright @ 2018 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
-  
+
   You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
-  
+
     https://imagemagick.org/script/license.php
-  
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -52,7 +52,7 @@ static ssize_t EncoderInitializer(const uint8_t *Data, const size_t Size, Magick
 
 extern "C" int LLVMFuzzerTestOneInput(const uint8_t *Data, size_t Size)
 {
-  if (Size < 1)
+  if (IsInvalidSize(Size))
     return 0;
   Magick::Image image;
   const ssize_t offset = EncoderInitializer(Data, Size, image);
