@@ -1,12 +1,12 @@
 /*
   Copyright @ 2018 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
-  
+
   You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
-  
+
     https://imagemagick.org/script/license.php
-  
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,8 +16,7 @@
 
 static int fuzzEncoderWithStringFilename(const std::string encoder, const uint8_t *Data, size_t Size, bool (*validate)(const std::string &) = NULL)
 {
-  // Allow a bit extra to make sure we do proper bounds checking in Magick++
-  if (Size > MagickPathExtent)
+  if (IsInvalidSize(Size))
     return 0;
 
   std::string fileName(reinterpret_cast<const char*>(Data), Size);
@@ -33,4 +32,4 @@ static int fuzzEncoderWithStringFilename(const std::string encoder, const uint8_
   catch (Magick::Exception &e) {
   }
   return 0;
-}
\ No newline at end of file
+}
